@@ -1,3 +1,6 @@
+from zeep import xsd
+
+
 class MutatieRegel:
     def __init__(
         self,
@@ -26,5 +29,5 @@ class MutatieRegel:
             BTWCode=self.btw_code,
             BTWPercentage=self.btw_percentage,
             TegenrekeningCode=self.tegenrekening_code,
-            KostenplaatsID=None,
+            KostenplaatsID=xsd.SkipValue,
         )
